<?php

namespace Drupal\field_quiz\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Url;
use Drupal\Core\Link;
use Drupal\node\NodeInterface;

/**
 * Default controller for the field_quiz module.
 */
class FieldQuizController extends ControllerBase {

  /**
   * Text, if the user answered wrong.
   *
   * @param \Drupal\node\NodeInterface $node
   *   The node the client form belongs to.
   *
   * @return array
   *   The text.
   */
  public function sorry(NodeInterface $node) {
    $config = $this->config('field_quiz.settings');
    $text = $config->get('field_quiz.test_answer_wrong');

    $elements[] = [
      '#type' => 'html_tag',
      '#tag' => 'p',
      '#attributes' => [
        'style' => 'color: red',
      ],
      '#value' => $this->t($text),
    ];

    $url = Url::fromRoute('entity.node.canonical', ['node' => $node->id()]);
    $project_link = Link::fromTextAndUrl(t('Please try again.'), $url);
    $project_link = $project_link->toRenderable();
    // If you need some attributes.
    $project_link['#attributes'] = [
      'class' => [
        'button',
        'button-action',
        'button--primary',
        'button--small',
      ],
    ];

    $elements[] = [
      '#type' => 'html_tag',
      '#tag' => 'p',
      '#attributes' => [],
      '#value' => render($project_link) ,
    ];

    return $elements;
  }

  /**
   * Text, if the user answered correctly.
   *
   * @return array
   *   The text.
   */
  public function success() {
    $config = $this->config('field_quiz.settings');
    $text = $config->get('field_quiz.test_answer_correct');

    $elements[] = [
      '#type' => 'html_tag',
      '#tag' => 'p',
      '#attributes' => [
        'style' => 'color: green',
      ],
      '#value' => $this->t($text),
    ];

    return $elements;
  }

}
